package com.zhilian.business.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.zhilian.business.domain.Markers;
import com.zhilian.business.domain.Vehicle;
import com.zhilian.business.domain.middle.VehicleMarkers;
import com.zhilian.business.service.MarkersService;
import com.zhilian.business.service.VehicleMarkersService;
import com.zhilian.business.service.VehicleService;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.controller.BaseController;
import com.zhilian.common.core.web.page.TableDataInfo;
import com.zhilian.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController {
    @Autowired
    private VehicleService vehicleService;

    @Autowired
    private VehicleMarkersService vehicleMarkersService;


    @Autowired
    private MarkersService markersService;


    /**
     * 查询车辆列表
     * @param vehicle
     * @return
     */
    @PostMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(@RequestBody Vehicle vehicle) {
        startPage();
        List<Vehicle> list = vehicleService.selectVehicleList(vehicle);
        return getDataTable(list);
    }

    /**
     * 新增车辆
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleInsert")
    public Result vehicleInsert(@RequestBody Vehicle vehicle){
        vehicle.setCreateBy(SecurityUtils.getUsername());
        vehicle.setCreateTime(new Date());
        return toAjax(vehicleService.save(vehicle));
    }

    /**
     * 修改车辆
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleUpdate")
    public Result vehicleUpdate(@RequestBody Vehicle vehicle){
        vehicle.setUpdateBy(SecurityUtils.getUsername());
        vehicle.setUpdateTime(new Date());

        //删除中间表全部关联数据
        vehicleMarkersService.removeAllVehicle(vehicle);

        //修改原表数据
        boolean update =vehicleService.updateById(vehicle);

        //重新添加中间表数据
        vehicleMarkersService.insert(vehicle);
        return toAjax(update);
    }

    /**
     * 根据车辆ID查询车辆与围栏中间表
     * @param vehicleId
     * @return
     */
    @PostMapping("/getVehicleMarkers/{vehicleId}")
    public List<VehicleMarkers> getVehicleMarkers(@PathVariable Long vehicleId){
        LambdaQueryWrapper<VehicleMarkers> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(VehicleMarkers::getVehicleId, vehicleId);
        return vehicleMarkersService.list(queryWrapper);
    }

//    @PostMapping("/getMarkers/{vehicleId}")
//    public List<Markers> getMarkers(@PathVariable Long vehicleId){
//        LambdaQueryWrapper<VehicleMarkers> queryWrapper = new LambdaQueryWrapper<>();
//        queryWrapper.eq(VehicleMarkers::getVehicleId, vehicleId);
//        List<VehicleMarkers> list = vehicleMarkersService.list(queryWrapper);
//        list.forEach(vehicleMarkers -> {
//            Markers markers = markersService.getById(vehicleMarkers.getMarkersId());
//        });
//        return null;
//    }
    /**
     * 删除车辆
     * @param vehicleId
     * @return
     */
    @PostMapping("/vehicleDelete/{vehicleId}")
    public Result vehicleDelete(@PathVariable Long vehicleId){
        getVehicleMarkers(vehicleId).forEach(vehicleMarkers -> {
            vehicleMarkersService.removeById(vehicleId);
        });
        return toAjax(vehicleService.removeById(vehicleId));
    }

    /**
     * 车辆绑定围栏
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleInsertMarkers")
    public Result vehicleInsertMarkers(@RequestBody Vehicle vehicle){
        boolean insert = vehicleMarkersService.insert(vehicle);
        return toAjax(insert);
    }
}
