package com.zhilian.resolver.service.impl.eventMalfunction;

import com.zhilian.common.resolver.domain.ResolverReportData;
import com.zhilian.common.resolver.domain.SysUserEnhancedServices;
import com.zhilian.resolver.mapper.UserMapper;
import com.zhilian.resolver.service.ResolverEventService;
import com.zhilian.resolver.service.ResolverReportInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
  * @ClassName MalfunctionEventServiceImpl
  * @Description 故障事件服务
  * @Author Can.J
  * @Date  2024/4/4 10:00
 */
@Slf4j
@Service("malfunction")
public class MalfunctionEventServiceImpl implements ResolverEventService {

    /**
     *  获取用信息 模拟故障
     */
    @Autowired
    private UserMapper userMapper;

    /**
     *  注入ResolverReportInfoService 业务层
     */
    @Autowired
    private ResolverReportInfoService resolverReportInfoService;

    @Override
    public void execute(ResolverReportData vehicleData) {
        log.info("故障事件开始执行");

        //模拟故障 获取用户信息
        for (SysUserEnhancedServices userEnhancedService : userMapper.getUserEnhancedServices()) {
            if(userEnhancedService.getEnhancedServicesId()==3 && userEnhancedService.getUseId()==102){
                if(isAnyFieldZero(vehicleData)){
                    resolverReportInfoService.saveDataToDatabaseByMalfunction(vehicleData);
                }

            }
        }


        log.info("故障事件结束");

    }
    private boolean isAnyFieldZero(ResolverReportData resolverReportData) {
        return resolverReportData.getChargingStatus() == 0 ||
                resolverReportData.getOperatingStatus() == 0 ||
                resolverReportData.getSocStatus() == 0 ||
                resolverReportData.getVehicleStatus() == 0 ||
                resolverReportData.getChargingEnergyStorageStatus() == 0 ||
                resolverReportData.getDriveMotorStatus() == 0 ||
                resolverReportData.getPositionStatus() == 0 ||
                resolverReportData.getEasStatus() == 0 ||
                resolverReportData.getPtcStatus() == 0 ||
                resolverReportData.getEpsStatus() == 0 ||
                resolverReportData.getAbsStatus() == 0 ||
                resolverReportData.getMcuStatus() == 0 ||
                resolverReportData.getHeatingStatus() == 0 ||
                resolverReportData.getBatteryStatus() == 0 ||
                resolverReportData.getBatteryInsulationStatus() == 0 ||
                resolverReportData.getDcdcStatus() == 0 ||
                resolverReportData.getChgStatus() == 0;
    }
    @Override
    public String getEventName() {
        return "malfunction";
    }
}
